@@ -48,7 +48,6 @@ impl LargeBotQueue {
         // tracing levels. It is made for the static_max_level_xxx features
         // And will return false if you do not use those features of if
         // You use the feature but then dynamically set a lower feature.
-        #[cfg(feature = "tracing")]
         if tracing::level_enabled!(tracing::Level::INFO) {
             let lock = limiter.0.lock().await;
 
@@ -70,9 +69,8 @@ impl LargeBotQueue {
 async fn waiter(mut rx: UnboundedReceiver<Sender<()>>) {
     const DUR: Duration = Duration::from_secs(6);
     while let Some(req) = rx.recv().await {
-        if let Err(_source) = req.send(()) {
-            #[cfg(feature = "tracing")]
-            tracing::warn!("skipping, send failed with: {:?}", _source);
+        if let Err(source) = req.send(()) {
+            tracing::warn!("skipping, send failed with: {source:?}");
         }
         sleep(DUR).await;
     }
@@ -89,13 +87,11 @@ impl Queue for LargeBotQueue {
 
         Box::pin(async move {
             self.limiter.get().await;
-            if let Err(_source) = self.buckets[bucket].send(tx) {
-                #[cfg(feature = "tracing")]
-                tracing::warn!("skipping, send failed with: {:?}", _source);
+            if let Err(source) = self.buckets[bucket].send(tx) {
+                tracing::warn!("skipping, send failed with: {source:?}");
                 return;
             }
 
-            #[cfg(feature = "tracing")]
             tracing::info!("waiting for allowance on shard {}", shard_id[0]);
 
             let _ = rx.await;
